<?php


	//lock file
	function hereiam_file_lock($handle)
	{
		$millisecond_timeout = 1000 * $timeout;
		
		$start_time = microtime();
		while(true)
		{
			if (flock($handle, LOCK_EX))// acquire an exclusive lock
			{
				return true;
			}
			else
			{
				// bow out if the attemp times out
				$time_taken = microtime() - $start_time;
				if ($time_taken > $millisecond_timeout)
				{
					return false;
				}
			}
		}
		//fall through. Should have been caught before here.
		return false;
	}
	
	function hereiam_file_unlock($handle)
	{
		//check if locked, and if so, unlock
		fflush($handle);            // flush output before releasing the lock
		flock($handle, LOCK_UN);    // release the lock
	}
	
	
	// helper functions simply for cleaing up the PHP files.

	# try and write to the log file. Keep trying for a period of time and then return
	function hereiam_log_append($filename, $msg, $timeout = 100)
	{
		$time_format = 'Y-m-d H:i:s';
		
		$retval = 1;
		$handle = fopen($filename, "a");
		
		$full_msg = "[" . date($time_format, time()) . "] : " . $msg;
		
		if (hereiam_file_lock($handle))
		{
			fwrite($handle, $full_msg);
			hereiam_file_unlock($handle);
			$retval = 0;
		}
		
		fclose($handle);
		return $retval;
	}
	
	//this function will return elements of the file according to the parameters.
	// reverse - if true, the array is returned with last item first
	// limit_to_last - this limits the size of the returned array to the number passed (0 items means return all))
	function hereiam_log($filename, $reverse = false, $limit_to_last = 0)
	{
		$log_array = file($filename);
		
		if ($limit_to_last > 0)
		{
			while(count($log_array) > $limit_to_last)
			{
				array_shift($log_array);
			}
		}
		
		if ($reverse)
		{	
			$log_array = array_reverse($log_array);
		}
		
		return $log_array;
	}
	
	
	// load the config file
	function hereiam_config($filename, $partner = 'zoneedit')
	{
		$full_config = parse_ini_file($filename, true);
		$config_settings = $full_config[$partner];
		
		$settings = array(
			"type"=>$config_settings["type"],
			"partner"=>$config_settings["partner"],
			"server"=>$config_settings["server"],
			"url"=>$config_settings["url"],
			"port"=>$config_settings["port"],
			"username"=>$config_settings["username"],
			"password"=>$config_settings["authentication"],
			"hostname"=>$config_settings["hostname"],
			"testurl"=>$config_settings["testurl"],
			"testport"=>$config_settings["testport"],
			"delay"=>$config_settings["delay"],
			"address"=>$config_settings["address"],
			"wildcard"=>($config_settings["wildcard"] == 1 ? 'yes' : 'no'),
			"autocheck"=>($config_settings["autocheck"] == 1 ? 'yes' : 'no'),
			"enabled"=>($config_settings["enabled"] == 1 ? 'yes' : 'no')
			);
			
			return $settings;
	}
	
	function hereiam_config_update($filename, $settings)
	{
		$time_format = 'Y-m-d H:i:s';
		$retval = 1;
		
		//open the file
		$handle = fopen($filename, "w");

		if (hereiam_file_lock($handle))
		{
			fwrite($handle, $msg);
			
			//fputs($handle, "# " . date($time_format, time()) . "\n");
			fputs($handle, "# " . date($time_format, time()) . "\n");
			fputs($handle, "[zoneedit]\n");
			
			fputs($handle, "#state items\n");
			fputs($handle, "enabled=" . $settings['enabled'] . "\n");
			fputs($handle, "autocheck=" . $settings['autocheck'] . "\n");
			fputs($handle, "delay=" . $settings['delay'] . "\n");
			fputs($handle, "\n");
			
			fputs($handle, "#partner specific items\n");
			fputs($handle, "partner=" . $settings['partner'] . "\n");
			fputs($handle, "type=" . $settings['type'] . "\n");
			fputs($handle, "server=" . $settings['server'] . "\n");
			fputs($handle, "url=" . $settings['url'] . "\n");
			fputs($handle, "port=" . $settings['port'] . "\n");
			fputs($handle, "username=" . $settings['username'] . "\n");
			fputs($handle, "authentication=" . $settings['password'] . "\n");
			fputs($handle, "\n");
			
			fputs($handle, "#hostname specific items\n");
			fputs($handle, "hostname=" . $settings['hostname'] . "\n");
			fputs($handle, "address=" . $settings['address'] . "\n");
			fputs($handle, "wildcard=" . $settings['wildcard'] . "\n");
			fputs($handle, "\n");
			
			fputs($handle, "#autocheck items\n");
			fputs($handle, "testurl=" . $settings['testurl'] . "\n");
			fputs($handle, "testport=" . $settings['testport'] . "\n");
			
			//ensure we force an update to the modified time
			hereiam_file_unlock($handle);
			
			touch($filename);
			
			$retval = 0;
		}
		
		fclose($handle);
		return $retval;
	}
	
	//check config agaist contents of the file, if different, return true.
	function hereiam_config_old($filename, $settings)
	{
		$config_settings = hereiam_config($filename);
		
		if (!empty($config_settings))
		{
			foreach($config_settings as $key => $value)
			{
				if ($settings[$key] != $value)
				{
					return true;
				}
			}
		}
		return false;
	}

?>